==> hs-gtk-0.12.3.1.tbz: lib/ghc-7.4.1/cabal/gtk-0.12.3.1/register.sh <==
#!/bin/sh
echo 'name: gtk
version: 0.12.3.1
id: gtk-0.12.3.1-8944cfaf379e3b30413e44996c4732fe

license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
stability: provisional
homepage: http://projects.haskell.org/gtk2hs/
package-url:
synopsis: Binding to the Gtk+ graphical user interface library.
description: This is the core library of the Gtk2Hs suite of libraries for Haskell
             based on Gtk+. Gtk+ is an extensive and mature multi-platform toolkit
             for creating graphical user interfaces.
category: Graphics
author: Axel Simon, Duncan Coutts and many others
exposed: True
exposed-modules: Graphics.UI.Gtk Graphics.UI.GtkInternals
                 Graphics.UI.Gtk.Abstract.Bin Graphics.UI.Gtk.Abstract.Box
                 Graphics.UI.Gtk.Abstract.ButtonBox
                 Graphics.UI.Gtk.Abstract.Container
                 Graphics.UI.Gtk.Abstract.IMContext Graphics.UI.Gtk.Abstract.Misc
                 Graphics.UI.Gtk.Abstract.Object Graphics.UI.Gtk.Abstract.Paned
                 Graphics.UI.Gtk.Abstract.Range Graphics.UI.Gtk.Abstract.Scale
                 Graphics.UI.Gtk.Abstract.Scrollbar
                 Graphics.UI.Gtk.Abstract.Separator Graphics.UI.Gtk.Abstract.Widget
                 Graphics.UI.Gtk.ActionMenuToolbar.Action
                 Graphics.UI.Gtk.ActionMenuToolbar.ActionGroup
                 Graphics.UI.Gtk.ActionMenuToolbar.RadioAction
                 Graphics.UI.Gtk.ActionMenuToolbar.RecentAction
                 Graphics.UI.Gtk.ActionMenuToolbar.ToggleAction
                 Graphics.UI.Gtk.ActionMenuToolbar.UIManager Graphics.UI.Gtk.Builder
                 Graphics.UI.Gtk.Buttons.Button Graphics.UI.Gtk.Buttons.CheckButton
                 Graphics.UI.Gtk.Buttons.RadioButton
                 Graphics.UI.Gtk.Buttons.ToggleButton
                 Graphics.UI.Gtk.Buttons.LinkButton
                 Graphics.UI.Gtk.Buttons.ScaleButton
                 Graphics.UI.Gtk.Buttons.VolumeButton Graphics.UI.Gtk.Cairo
                 Graphics.UI.Gtk.Display.AccelLabel Graphics.UI.Gtk.Display.Image
                 Graphics.UI.Gtk.Display.Label Graphics.UI.Gtk.Display.ProgressBar
                 Graphics.UI.Gtk.Display.Spinner Graphics.UI.Gtk.Display.Statusbar
                 Graphics.UI.Gtk.Display.StatusIcon Graphics.UI.Gtk.Display.InfoBar
                 Graphics.UI.Gtk.Embedding.Embedding Graphics.UI.Gtk.Embedding.Plug
                 Graphics.UI.Gtk.Embedding.Socket Graphics.UI.Gtk.Entry.Editable
                 Graphics.UI.Gtk.Entry.Entry Graphics.UI.Gtk.Entry.EntryBuffer
                 Graphics.UI.Gtk.Entry.EntryCompletion Graphics.UI.Gtk.Entry.HScale
                 Graphics.UI.Gtk.Entry.SpinButton Graphics.UI.Gtk.Entry.VScale
                 Graphics.UI.Gtk.Gdk.AppLaunchContext Graphics.UI.Gtk.Gdk.Cursor
                 Graphics.UI.Gtk.Gdk.Keymap Graphics.UI.Gtk.Gdk.Display
                 Graphics.UI.Gtk.Gdk.DisplayManager Graphics.UI.Gtk.Gdk.Drawable
                 Graphics.UI.Gtk.Gdk.DrawWindow Graphics.UI.Gtk.Gdk.EventM
                 Graphics.UI.Gtk.Gdk.Events Graphics.UI.Gtk.Gdk.GC
                 Graphics.UI.Gtk.Gdk.Gdk Graphics.UI.Gtk.Gdk.Keys
                 Graphics.UI.Gtk.Gdk.Pixbuf Graphics.UI.Gtk.Gdk.PixbufAnimation
                 Graphics.UI.Gtk.Gdk.Pixmap Graphics.UI.Gtk.Gdk.Region
                 Graphics.UI.Gtk.Gdk.Screen Graphics.UI.Gtk.General.Clipboard
                 Graphics.UI.Gtk.General.Drag Graphics.UI.Gtk.General.General
                 Graphics.UI.Gtk.General.IconFactory
                 Graphics.UI.Gtk.General.IconTheme Graphics.UI.Gtk.General.RcStyle
                 Graphics.UI.Gtk.General.Selection
                 Graphics.UI.Gtk.General.StockItems Graphics.UI.Gtk.General.Style
                 Graphics.UI.Gtk.Layout.Alignment Graphics.UI.Gtk.Layout.AspectFrame
                 Graphics.UI.Gtk.Layout.Expander Graphics.UI.Gtk.Layout.Fixed
                 Graphics.UI.Gtk.Layout.HBox Graphics.UI.Gtk.Layout.HButtonBox
                 Graphics.UI.Gtk.Layout.HPaned Graphics.UI.Gtk.Layout.Layout
                 Graphics.UI.Gtk.Layout.Notebook Graphics.UI.Gtk.Layout.Table
                 Graphics.UI.Gtk.Layout.VBox Graphics.UI.Gtk.Layout.VButtonBox
                 Graphics.UI.Gtk.Layout.VPaned
                 Graphics.UI.Gtk.MenuComboToolbar.CheckMenuItem
                 Graphics.UI.Gtk.MenuComboToolbar.Combo
                 Graphics.UI.Gtk.MenuComboToolbar.ComboBox
                 Graphics.UI.Gtk.MenuComboToolbar.ComboBoxEntry
                 Graphics.UI.Gtk.MenuComboToolbar.ImageMenuItem
                 Graphics.UI.Gtk.MenuComboToolbar.Menu
                 Graphics.UI.Gtk.MenuComboToolbar.MenuBar
                 Graphics.UI.Gtk.MenuComboToolbar.MenuItem
                 Graphics.UI.Gtk.MenuComboToolbar.MenuShell
                 Graphics.UI.Gtk.MenuComboToolbar.MenuToolButton
                 Graphics.UI.Gtk.MenuComboToolbar.OptionMenu
                 Graphics.UI.Gtk.MenuComboToolbar.RadioMenuItem
                 Graphics.UI.Gtk.MenuComboToolbar.RadioToolButton
                 Graphics.UI.Gtk.MenuComboToolbar.SeparatorMenuItem
                 Graphics.UI.Gtk.MenuComboToolbar.SeparatorToolItem
                 Graphics.UI.Gtk.MenuComboToolbar.TearoffMenuItem
                 Graphics.UI.Gtk.MenuComboToolbar.ToggleToolButton
                 Graphics.UI.Gtk.MenuComboToolbar.Toolbar
                 Graphics.UI.Gtk.MenuComboToolbar.ToolButton
                 Graphics.UI.Gtk.MenuComboToolbar.ToolItem
                 Graphics.UI.Gtk.MenuComboToolbar.ToolItemGroup
                 Graphics.UI.Gtk.MenuComboToolbar.ToolPalette
                 Graphics.UI.Gtk.Misc.Accessible Graphics.UI.Gtk.Misc.Adjustment
                 Graphics.UI.Gtk.Misc.Arrow Graphics.UI.Gtk.Misc.Calendar
                 Graphics.UI.Gtk.Misc.DrawingArea Graphics.UI.Gtk.Misc.EventBox
                 Graphics.UI.Gtk.Misc.HandleBox Graphics.UI.Gtk.Misc.IMMulticontext
                 Graphics.UI.Gtk.Misc.IMContextSimple Graphics.UI.Gtk.Misc.SizeGroup
                 Graphics.UI.Gtk.Misc.Tooltip Graphics.UI.Gtk.Misc.Tooltips
                 Graphics.UI.Gtk.Misc.Viewport Graphics.UI.Gtk.ModelView
                 Graphics.UI.Gtk.ModelView.CellEditable
                 Graphics.UI.Gtk.ModelView.CellLayout
                 Graphics.UI.Gtk.ModelView.CellRenderer
                 Graphics.UI.Gtk.ModelView.CellRendererSpinner
                 Graphics.UI.Gtk.ModelView.CellRendererCombo
                 Graphics.UI.Gtk.ModelView.CellRendererPixbuf
                 Graphics.UI.Gtk.ModelView.CellRendererProgress
                 Graphics.UI.Gtk.ModelView.CellRendererText
                 Graphics.UI.Gtk.ModelView.CellRendererAccel
                 Graphics.UI.Gtk.ModelView.CellRendererSpin
                 Graphics.UI.Gtk.ModelView.CellRendererToggle
                 Graphics.UI.Gtk.ModelView.CellView
                 Graphics.UI.Gtk.ModelView.CustomStore
                 Graphics.UI.Gtk.ModelView.IconView
                 Graphics.UI.Gtk.ModelView.ListStore
                 Graphics.UI.Gtk.ModelView.TreeDrag
                 Graphics.UI.Gtk.ModelView.TreeModel
                 Graphics.UI.Gtk.ModelView.TreeModelFilter
                 Graphics.UI.Gtk.ModelView.TreeModelSort
                 Graphics.UI.Gtk.ModelView.TreeRowReference
                 Graphics.UI.Gtk.ModelView.TreeSelection
                 Graphics.UI.Gtk.ModelView.TreeSortable
                 Graphics.UI.Gtk.ModelView.TreeStore
                 Graphics.UI.Gtk.ModelView.TreeView
                 Graphics.UI.Gtk.ModelView.TreeViewColumn
                 Graphics.UI.Gtk.Multiline.TextBuffer
                 Graphics.UI.Gtk.Multiline.TextIter
                 Graphics.UI.Gtk.Multiline.TextMark
                 Graphics.UI.Gtk.Multiline.TextTag
                 Graphics.UI.Gtk.Multiline.TextTagTable
                 Graphics.UI.Gtk.Multiline.TextView Graphics.UI.Gtk.Ornaments.Frame
                 Graphics.UI.Gtk.Ornaments.HSeparator
                 Graphics.UI.Gtk.Ornaments.VSeparator
                 Graphics.UI.Gtk.Printing.PaperSize
                 Graphics.UI.Gtk.Printing.PageSetup
                 Graphics.UI.Gtk.Printing.PrintContext
                 Graphics.UI.Gtk.Printing.PrintOperation
                 Graphics.UI.Gtk.Printing.PrintSettings
                 Graphics.UI.Gtk.Recent.RecentChooserMenu
                 Graphics.UI.Gtk.Recent.RecentChooserWidget
                 Graphics.UI.Gtk.Recent.RecentFilter
                 Graphics.UI.Gtk.Recent.RecentManager
                 Graphics.UI.Gtk.Recent.RecentInfo
                 Graphics.UI.Gtk.Recent.RecentChooser
                 Graphics.UI.Gtk.Scrolling.HScrollbar
                 Graphics.UI.Gtk.Scrolling.ScrolledWindow
                 Graphics.UI.Gtk.Scrolling.VScrollbar
                 Graphics.UI.Gtk.Selectors.ColorButton
                 Graphics.UI.Gtk.Selectors.ColorSelection
                 Graphics.UI.Gtk.Selectors.ColorSelectionDialog
                 Graphics.UI.Gtk.Selectors.FileChooser
                 Graphics.UI.Gtk.Selectors.FileChooserButton
                 Graphics.UI.Gtk.Selectors.FileChooserDialog
                 Graphics.UI.Gtk.Selectors.FileChooserWidget
                 Graphics.UI.Gtk.Selectors.FileFilter
                 Graphics.UI.Gtk.Selectors.FileSelection
                 Graphics.UI.Gtk.Selectors.FontButton
                 Graphics.UI.Gtk.Selectors.FontSelection
                 Graphics.UI.Gtk.Selectors.FontSelectionDialog
                 Graphics.UI.Gtk.Selectors.HSV Graphics.UI.Gtk.Special.Ruler
                 Graphics.UI.Gtk.Special.HRuler Graphics.UI.Gtk.Special.VRuler
                 Graphics.UI.Gtk.Windows.AboutDialog
                 Graphics.UI.Gtk.Windows.Assistant Graphics.UI.Gtk.Windows.Dialog
                 Graphics.UI.Gtk.Windows.Invisible
                 Graphics.UI.Gtk.Windows.MessageDialog
                 Graphics.UI.Gtk.Windows.Window
                 Graphics.UI.Gtk.Windows.OffscreenWindow
                 Graphics.UI.Gtk.Windows.WindowGroup Graphics.UI.Gtk.General.Enums
hidden-modules: Graphics.UI.Gtk.Gdk.Enums
                Graphics.UI.Gtk.Gdk.PixbufData Graphics.UI.Gtk.General.Structs
                Graphics.UI.Gtk.ModelView.Types Graphics.UI.Gtk.ModelView.Sequence
                Graphics.UI.Gtk.Multiline.Types
                Graphics.UI.Gtk.Abstract.ContainerChildProperties
                Graphics.UI.Gtk.General.DNDTypes Graphics.UI.Gtk.General.Threading
                Graphics.UI.Gtk.Types Graphics.UI.Gtk.Signals
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.1/cabal/gtk-0.12.3.1
library-dirs: /usr/local/lib/ghc-7.4.1/cabal/gtk-0.12.3.1
              /usr/local/lib
hs-libraries: HSgtk-0.12.3.1
extra-libraries: gtk-x11-2.0 gdk-x11-2.0 pangocairo-1.0 Xext
                 Xrender Xinerama Xi Xrandr Xcursor Xcomposite Xdamage Xfixes X11
                 atk-1.0 cairo gdk_pixbuf-2.0 gio-2.0 pangoft2-1.0 pango-1.0 m
                 gobject-2.0 gthread-2.0 gmodule-2.0 glib-2.0 freetype fontconfig
extra-ghci-libraries:
include-dirs: /usr/local/include /usr/local/include/gtk-2.0
              /usr/local/include/gio-unix-2.0/ /usr/local/include/atk-1.0
              /usr/local/include/cairo /usr/local/include/pixman-1
              /usr/local/include/gdk-pixbuf-2.0 /usr/local/include/libpng15
              /usr/local/include/pango-1.0 /usr/local/include/glib-2.0
              /usr/local/include/freetype2
includes:
depends: array-0.4.0.0-59d1cc0e7979167b002f021942d60f46
         base-4.5.0.0-3459bca6d8e46666b517e8bb2e033728
         bytestring-0.9.2.1-6ff76798e80a342ff74a1c8bcb3f4124
         cairo-0.12.3.1-72943041ac0a8f5f7b9a3859e6d71fe1
         containers-0.4.2.1-cfc6420ecc2194c9ed977b06bdfd9e69
         gio-0.12.3-d4fa99730a97194e714a9725fe2ce6eb
         glib-0.12.3.1-b8fe1b8554ac9f9afc9af7e353ede55d
         mtl-2.1.1-801101765c9185fec3b8dbd5355f5550
         pango-0.12.3-86ce88701ca575a64c78e01efb6107e7
hugs-options:
cc-options:
ld-options: -pthread
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.1/cabal/gtk-0.12.3.1/html/gtk.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.1/cabal/gtk-0.12.3.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-gtk-0.12.4_1.tbz: lib/ghc-7.4.2/cabal/gtk-0.12.4/register.sh <==
#!/bin/sh
echo 'name: gtk
version: 0.12.4
id: gtk-0.12.4-1951292e52dab9a09dcaa043d8e9593e

license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
stability: provisional
homepage: http://projects.haskell.org/gtk2hs/
package-url:
synopsis: Binding to the Gtk+ graphical user interface library.
description: This is the core library of the Gtk2Hs suite of libraries for Haskell
             based on Gtk+. Gtk+ is an extensive and mature multi-platform toolkit
             for creating graphical user interfaces.
category: Graphics
author: Axel Simon, Duncan Coutts and many others
exposed: True
exposed-modules: Graphics.UI.Gtk Graphics.UI.GtkInternals
                 Graphics.UI.Gtk.Abstract.Bin Graphics.UI.Gtk.Abstract.Box
                 Graphics.UI.Gtk.Abstract.ButtonBox
                 Graphics.UI.Gtk.Abstract.Container
                 Graphics.UI.Gtk.Abstract.IMContext Graphics.UI.Gtk.Abstract.Misc
                 Graphics.UI.Gtk.Abstract.Object Graphics.UI.Gtk.Abstract.Paned
                 Graphics.UI.Gtk.Abstract.Range Graphics.UI.Gtk.Abstract.Scale
                 Graphics.UI.Gtk.Abstract.Scrollbar
                 Graphics.UI.Gtk.Abstract.Separator Graphics.UI.Gtk.Abstract.Widget
                 Graphics.UI.Gtk.ActionMenuToolbar.Action
                 Graphics.UI.Gtk.ActionMenuToolbar.ActionGroup
                 Graphics.UI.Gtk.ActionMenuToolbar.RadioAction
                 Graphics.UI.Gtk.ActionMenuToolbar.RecentAction
                 Graphics.UI.Gtk.ActionMenuToolbar.ToggleAction
                 Graphics.UI.Gtk.ActionMenuToolbar.UIManager Graphics.UI.Gtk.Builder
                 Graphics.UI.Gtk.Buttons.Button Graphics.UI.Gtk.Buttons.CheckButton
                 Graphics.UI.Gtk.Buttons.RadioButton
                 Graphics.UI.Gtk.Buttons.ToggleButton
                 Graphics.UI.Gtk.Buttons.LinkButton
                 Graphics.UI.Gtk.Buttons.ScaleButton
                 Graphics.UI.Gtk.Buttons.VolumeButton Graphics.UI.Gtk.Cairo
                 Graphics.UI.Gtk.Display.AccelLabel Graphics.UI.Gtk.Display.Image
                 Graphics.UI.Gtk.Display.Label Graphics.UI.Gtk.Display.ProgressBar
                 Graphics.UI.Gtk.Display.Spinner Graphics.UI.Gtk.Display.Statusbar
                 Graphics.UI.Gtk.Display.StatusIcon Graphics.UI.Gtk.Display.InfoBar
                 Graphics.UI.Gtk.Embedding.Embedding Graphics.UI.Gtk.Embedding.Plug
                 Graphics.UI.Gtk.Embedding.Socket Graphics.UI.Gtk.Entry.Editable
                 Graphics.UI.Gtk.Entry.Entry Graphics.UI.Gtk.Entry.EntryBuffer
                 Graphics.UI.Gtk.Entry.EntryCompletion Graphics.UI.Gtk.Entry.HScale
                 Graphics.UI.Gtk.Entry.SpinButton Graphics.UI.Gtk.Entry.VScale
                 Graphics.UI.Gtk.Gdk.AppLaunchContext Graphics.UI.Gtk.Gdk.Cursor
                 Graphics.UI.Gtk.Gdk.Keymap Graphics.UI.Gtk.Gdk.Display
                 Graphics.UI.Gtk.Gdk.DisplayManager Graphics.UI.Gtk.Gdk.Drawable
                 Graphics.UI.Gtk.Gdk.DrawWindow Graphics.UI.Gtk.Gdk.EventM
                 Graphics.UI.Gtk.Gdk.Events Graphics.UI.Gtk.Gdk.GC
                 Graphics.UI.Gtk.Gdk.Gdk Graphics.UI.Gtk.Gdk.Keys
                 Graphics.UI.Gtk.Gdk.Pixbuf Graphics.UI.Gtk.Gdk.PixbufAnimation
                 Graphics.UI.Gtk.Gdk.Pixmap Graphics.UI.Gtk.Gdk.Region
                 Graphics.UI.Gtk.Gdk.Screen Graphics.UI.Gtk.General.Clipboard
                 Graphics.UI.Gtk.General.Drag Graphics.UI.Gtk.General.General
                 Graphics.UI.Gtk.General.IconFactory
                 Graphics.UI.Gtk.General.IconTheme Graphics.UI.Gtk.General.RcStyle
                 Graphics.UI.Gtk.General.Selection
                 Graphics.UI.Gtk.General.StockItems Graphics.UI.Gtk.General.Style
                 Graphics.UI.Gtk.Layout.Alignment Graphics.UI.Gtk.Layout.AspectFrame
                 Graphics.UI.Gtk.Layout.Expander Graphics.UI.Gtk.Layout.Fixed
                 Graphics.UI.Gtk.Layout.HBox Graphics.UI.Gtk.Layout.HButtonBox
                 Graphics.UI.Gtk.Layout.HPaned Graphics.UI.Gtk.Layout.Layout
                 Graphics.UI.Gtk.Layout.Notebook Graphics.UI.Gtk.Layout.Table
                 Graphics.UI.Gtk.Layout.VBox Graphics.UI.Gtk.Layout.VButtonBox
                 Graphics.UI.Gtk.Layout.VPaned
                 Graphics.UI.Gtk.MenuComboToolbar.CheckMenuItem
                 Graphics.UI.Gtk.MenuComboToolbar.Combo
                 Graphics.UI.Gtk.MenuComboToolbar.ComboBox
                 Graphics.UI.Gtk.MenuComboToolbar.ComboBoxEntry
                 Graphics.UI.Gtk.MenuComboToolbar.ImageMenuItem
                 Graphics.UI.Gtk.MenuComboToolbar.Menu
                 Graphics.UI.Gtk.MenuComboToolbar.MenuBar
                 Graphics.UI.Gtk.MenuComboToolbar.MenuItem
                 Graphics.UI.Gtk.MenuComboToolbar.MenuShell
                 Graphics.UI.Gtk.MenuComboToolbar.MenuToolButton
                 Graphics.UI.Gtk.MenuComboToolbar.OptionMenu
                 Graphics.UI.Gtk.MenuComboToolbar.RadioMenuItem
                 Graphics.UI.Gtk.MenuComboToolbar.RadioToolButton
                 Graphics.UI.Gtk.MenuComboToolbar.SeparatorMenuItem
                 Graphics.UI.Gtk.MenuComboToolbar.SeparatorToolItem
                 Graphics.UI.Gtk.MenuComboToolbar.TearoffMenuItem
                 Graphics.UI.Gtk.MenuComboToolbar.ToggleToolButton
                 Graphics.UI.Gtk.MenuComboToolbar.Toolbar
                 Graphics.UI.Gtk.MenuComboToolbar.ToolButton
                 Graphics.UI.Gtk.MenuComboToolbar.ToolItem
                 Graphics.UI.Gtk.MenuComboToolbar.ToolItemGroup
                 Graphics.UI.Gtk.MenuComboToolbar.ToolPalette
                 Graphics.UI.Gtk.Misc.Accessible Graphics.UI.Gtk.Misc.Adjustment
                 Graphics.UI.Gtk.Misc.Arrow Graphics.UI.Gtk.Misc.Calendar
                 Graphics.UI.Gtk.Misc.DrawingArea Graphics.UI.Gtk.Misc.EventBox
                 Graphics.UI.Gtk.Misc.HandleBox Graphics.UI.Gtk.Misc.IMMulticontext
                 Graphics.UI.Gtk.Misc.IMContextSimple Graphics.UI.Gtk.Misc.SizeGroup
                 Graphics.UI.Gtk.Misc.Tooltip Graphics.UI.Gtk.Misc.Tooltips
                 Graphics.UI.Gtk.Misc.Viewport Graphics.UI.Gtk.ModelView
                 Graphics.UI.Gtk.ModelView.CellEditable
                 Graphics.UI.Gtk.ModelView.CellLayout
                 Graphics.UI.Gtk.ModelView.CellRenderer
                 Graphics.UI.Gtk.ModelView.CellRendererSpinner
                 Graphics.UI.Gtk.ModelView.CellRendererCombo
                 Graphics.UI.Gtk.ModelView.CellRendererPixbuf
                 Graphics.UI.Gtk.ModelView.CellRendererProgress
                 Graphics.UI.Gtk.ModelView.CellRendererText
                 Graphics.UI.Gtk.ModelView.CellRendererAccel
                 Graphics.UI.Gtk.ModelView.CellRendererSpin
                 Graphics.UI.Gtk.ModelView.CellRendererToggle
                 Graphics.UI.Gtk.ModelView.CellView
                 Graphics.UI.Gtk.ModelView.CustomStore
                 Graphics.UI.Gtk.ModelView.IconView
                 Graphics.UI.Gtk.ModelView.ListStore
                 Graphics.UI.Gtk.ModelView.TreeDrag
                 Graphics.UI.Gtk.ModelView.TreeModel
                 Graphics.UI.Gtk.ModelView.TreeModelFilter
                 Graphics.UI.Gtk.ModelView.TreeModelSort
                 Graphics.UI.Gtk.ModelView.TreeRowReference
                 Graphics.UI.Gtk.ModelView.TreeSelection
                 Graphics.UI.Gtk.ModelView.TreeSortable
                 Graphics.UI.Gtk.ModelView.TreeStore
                 Graphics.UI.Gtk.ModelView.TreeView
                 Graphics.UI.Gtk.ModelView.TreeViewColumn
                 Graphics.UI.Gtk.Multiline.TextBuffer
                 Graphics.UI.Gtk.Multiline.TextIter
                 Graphics.UI.Gtk.Multiline.TextMark
                 Graphics.UI.Gtk.Multiline.TextTag
                 Graphics.UI.Gtk.Multiline.TextTagTable
                 Graphics.UI.Gtk.Multiline.TextView Graphics.UI.Gtk.Ornaments.Frame
                 Graphics.UI.Gtk.Ornaments.HSeparator
                 Graphics.UI.Gtk.Ornaments.VSeparator
                 Graphics.UI.Gtk.Printing.PaperSize
                 Graphics.UI.Gtk.Printing.PageSetup
                 Graphics.UI.Gtk.Printing.PrintContext
                 Graphics.UI.Gtk.Printing.PrintOperation
                 Graphics.UI.Gtk.Printing.PrintSettings
                 Graphics.UI.Gtk.Recent.RecentChooserMenu
                 Graphics.UI.Gtk.Recent.RecentChooserWidget
                 Graphics.UI.Gtk.Recent.RecentFilter
                 Graphics.UI.Gtk.Recent.RecentManager
                 Graphics.UI.Gtk.Recent.RecentInfo
                 Graphics.UI.Gtk.Recent.RecentChooser
                 Graphics.UI.Gtk.Scrolling.HScrollbar
                 Graphics.UI.Gtk.Scrolling.ScrolledWindow
                 Graphics.UI.Gtk.Scrolling.VScrollbar
                 Graphics.UI.Gtk.Selectors.ColorButton
                 Graphics.UI.Gtk.Selectors.ColorSelection
                 Graphics.UI.Gtk.Selectors.ColorSelectionDialog
                 Graphics.UI.Gtk.Selectors.FileChooser
                 Graphics.UI.Gtk.Selectors.FileChooserButton
                 Graphics.UI.Gtk.Selectors.FileChooserDialog
                 Graphics.UI.Gtk.Selectors.FileChooserWidget
                 Graphics.UI.Gtk.Selectors.FileFilter
                 Graphics.UI.Gtk.Selectors.FileSelection
                 Graphics.UI.Gtk.Selectors.FontButton
                 Graphics.UI.Gtk.Selectors.FontSelection
                 Graphics.UI.Gtk.Selectors.FontSelectionDialog
                 Graphics.UI.Gtk.Selectors.HSV Graphics.UI.Gtk.Special.Ruler
                 Graphics.UI.Gtk.Special.HRuler Graphics.UI.Gtk.Special.VRuler
                 Graphics.UI.Gtk.Windows.AboutDialog
                 Graphics.UI.Gtk.Windows.Assistant Graphics.UI.Gtk.Windows.Dialog
                 Graphics.UI.Gtk.Windows.Invisible
                 Graphics.UI.Gtk.Windows.MessageDialog
                 Graphics.UI.Gtk.Windows.Window
                 Graphics.UI.Gtk.Windows.OffscreenWindow
                 Graphics.UI.Gtk.Windows.WindowGroup Graphics.UI.Gtk.General.Enums
hidden-modules: Graphics.UI.Gtk.Gdk.Enums
                Graphics.UI.Gtk.Gdk.PixbufData Graphics.UI.Gtk.General.Structs
                Graphics.UI.Gtk.ModelView.Types Graphics.UI.Gtk.ModelView.Sequence
                Graphics.UI.Gtk.Multiline.Types
                Graphics.UI.Gtk.Abstract.ContainerChildProperties
                Graphics.UI.Gtk.General.DNDTypes Graphics.UI.Gtk.General.Threading
                Graphics.UI.Gtk.Types Graphics.UI.Gtk.Signals
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.2/cabal/gtk-0.12.4
library-dirs: /usr/local/lib/ghc-7.4.2/cabal/gtk-0.12.4
              /usr/local/lib
hs-libraries: HSgtk-0.12.4
extra-libraries: gthread-2.0 gtk-x11-2.0 gdk-x11-2.0 pangocairo-1.0
                 Xext Xrender Xinerama Xi Xrandr Xcursor Xcomposite Xdamage Xfixes
                 X11 atk-1.0 cairo gdk_pixbuf-2.0 gio-2.0 pangoft2-1.0 pango-1.0
                 gobject-2.0 glib-2.0 freetype fontconfig
extra-ghci-libraries:
include-dirs: /usr/local/include /usr/local/include/gtk-2.0
              /usr/local/include/gio-unix-2.0/ /usr/local/include/atk-1.0
              /usr/local/include/cairo /usr/local/include/pixman-1
              /usr/local/include/gdk-pixbuf-2.0 /usr/local/include/libpng15
              /usr/local/include/pango-1.0 /usr/local/include/glib-2.0
              /usr/local/include/freetype2
includes:
depends: array-0.4.0.0-4f6c2a594155b0b953c1cf0f54040f61
         base-4.5.1.0-12fddc14a7babb909dd3843e453b5660
         bytestring-0.9.2.1-e22c77999d0db34f3ca8de7082a3ffd5
         cairo-0.12.4-1f1291779a1b223745fc6aed5e8e5354
         containers-0.4.2.1-efa59805336a77490296ae3897cecb87
         gio-0.12.4-43cce1ef392274fea6c9a03808b6ad1e
         glib-0.12.4-dc7ab9255cefef81913c196fd3b53d89
         mtl-2.1.2-cf6082d8d4c6758d23401302efadd028
         pango-0.12.4-11c48ece25d4f5d48c644211de3abce8
hugs-options:
cc-options:
ld-options: -pthread
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.2/cabal/gtk-0.12.4/html/gtk.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.2/cabal/gtk-0.12.4/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
